@@ -5,7 +5,9 @@
  * Licensed under the GPL-2
  */
 
-#define WRAPPER_ARGS_PROTO const char *filename, const struct timeval times[]
+#define WRAPPER_ARGS_PROTO const char *filename, const struct timeval times[2]
 #define WRAPPER_ARGS filename, times
-#define WRAPPER_SAFE() SB_SAFE(filename)
+#ifndef WRAPPER_SAFE
+# define WRAPPER_SAFE() SB_SAFE(filename)
+#endif
 #include "__wrapper_simple.c"
