@@ -6,7 +6,6 @@ addwrite $PWD
 touch file || exit 1
 
 adddeny $PWD
-export SANDBOX_LOG=$PWD/sb.log
 # we cant check exit status as ptrace code kills child
 linkat-0 -1,EACCES AT_FDCWD file AT_FDCWD file-linked 0 #|| exit 1
-test -s sb.log
+test -s sandbox.log
